pub struct ProcessIdentity { /* private fields */ }Expand description
Stable identity for one registration of an operating-system PID.
PIDs can be reused after a child is reaped. The generation prevents an old exec session from signalling a newer process that received the same PID.
Implementations