Module serial

Module serial 

Virtio serial port discovery.

Constants

AGENT_PORT_NAME
Re-export the canonical agent port name from the protocol crate. Virtio-console port name for the agent channel.

Functions

find_serial_port
Discovers the device path for a virtio serial port by its name.