BulkSessionOutput

Struct BulkSessionOutput 

pub struct BulkSessionOutput {
    pub record: BulkRecord,
    pub activity: RawActivity,
}
Raw bulk output plus activity metadata known by its producer.

Fields

record: BulkRecord

Validated record whose payload is written with the fixed header via writev.

activity: RawActivity

Activity represented by the record.

Implementations

Source

impl BulkSessionOutput

pub fn new(record: BulkRecord, activity: RawActivity) -> Self

Creates a raw bulk output event.