RawSessionOutput

Struct RawSessionOutput 

pub struct RawSessionOutput {
    pub frame: Vec<u8>,
    pub activity: RawActivity,
    pub completion: Option<RawSessionCompletion>,
}
Pre-encoded session output plus the accounting metadata known by its producer.

Fields

frame: Vec<u8>

Encoded protocol frame bytes.

activity: RawActivity

Activity represented by the frame.

completion: Option<RawSessionCompletion>

Session table entry completed by the frame, if any.

Implementations

Source

impl RawSessionOutput

pub fn new( frame: Vec<u8>, activity: RawActivity, completion: Option<RawSessionCompletion>, ) -> Self

Creates pre-encoded output with activity metadata.