pub struct SessionOutputEnvelope {
pub generation: u64,
pub id: u32,
pub incarnation: Option<ClientIncarnation>,
pub output: SessionOutput,
/* private fields */
}Expand description
One queued session event and the data-budget capacity owned by its buffer.
Fields
generation: u64Host attachment generation captured when the producer was created.
id: u32Correlation ID for the session event.
incarnation: Option<ClientIncarnation>Dual-port range owner captured when the session was created.
output: SessionOutputEvent consumed by the main serial loop.