Main agent loop: serial I/O, session management, heartbeat.
Functions
- open_
serial_ port - Opens the agent virtio-serial port once for early boot handshakes and the agent loop.
- report_
init_ context - Reports init-time guest context to the host and waits for an acknowledgement.
- run
- Runs the main agent loop.