Guest-side network configuration from MSB_NET* environment variables.
Configures the guest network interface using ioctls and netlink, following
the parameters provided by the host supervisor via msbnet.
This module only performs real work on Linux. On other platforms, it is a no-op.
Functions
- apply_
network_ config - Applies network configuration from
MSB_NET*environment variables.