Guest-side network configuration from MSB_NET* environment variables.
Configures the guest network interface using ioctls and netlink, following the parameters from host.
Guest-side network configuration from MSB_NET* environment variables.
Configures the guest network interface using ioctls and netlink, following the parameters from host.