Exec session management: spawning processes with PTY or pipe I/O.
Structs
- Bulk
Session Output - Raw bulk output plus activity metadata known by its producer.
- Exec
Session - An active exec session handle for sending input to a running process.
- RawActivity
- Activity represented by a pre-encoded session frame.
- RawSession
Output - Pre-encoded session output plus the accounting metadata known by its producer.
- Session
Output Envelope - One queued session event and the data-budget capacity owned by its buffer.
- Session
Output Permit - Capacity reserved before a producer reads or encodes a data-bearing event.
- Session
Output Sender - Cloneable producer for the byte-bounded session output queue.
Enums
- Bulk
Output Command - Lifecycle commands processed ahead of queued dedicated-lane output.
- RawSession
Completion - Session table entry completed by a pre-encoded session frame.
- Session
Output - Output from a session that the agent loop should forward to the host.