Module session

Module session 

Exec session management: spawning processes with PTY or pipe I/O.

Structs

ExecSession
An active exec session handle for sending input to a running process.
RawActivity
Activity represented by a pre-encoded session frame.
RawSessionOutput
Pre-encoded session output plus the accounting metadata known by its producer.

Enums

RawSessionCompletion
Session table entry completed by a pre-encoded session frame.
SessionOutput
Output from a session that the agent loop should forward to the host.