Exec session management: spawning processes with PTY or pipe I/O.
Structs
- Exec
Session - An active exec session handle for sending input to a running process.
- RawActivity
- Activity represented by a pre-encoded session frame.
- RawSession
Output - Pre-encoded session output plus the accounting metadata known by its producer.
Enums
- RawSession
Completion - Session table entry completed by a pre-encoded session frame.
- Session
Output - Output from a session that the agent loop should forward to the host.