Module session

Module session 

Exec session management: spawning processes with PTY or pipe I/O.

Structs

ExecSession
An active exec session handle for sending input to a running process.

Enums

SessionOutput
Output from a session that the agent loop should forward to the host.