Exec session management: spawning processes with PTY or pipe I/O.
Structs
- Exec
Session - An active exec session handle for sending input to a running process.
Enums
- Session
Output - Output from a session that the agent loop should forward to the host.