pub struct BulkSessionOutput {
pub record: BulkRecord,
pub activity: RawActivity,
}Expand description
Raw bulk output plus activity metadata known by its producer.
Fields
record: BulkRecordValidated record whose payload is written with the fixed header via writev.
activity: RawActivityActivity represented by the record.
Implementations
Sourceimpl BulkSessionOutput
impl BulkSessionOutput
Sourcepub fn new(record: BulkRecord, activity: RawActivity) -> Self
pub fn new(record: BulkRecord, activity: RawActivity) -> Self
Creates a raw bulk output event.