pub struct RawSessionOutput {
pub frame: Vec<u8>,
pub activity: RawActivity,
pub completion: Option<RawSessionCompletion>,
}Expand description
Pre-encoded session output plus the accounting metadata known by its producer.
Fields
frame: Vec<u8>Encoded protocol frame bytes.
activity: RawActivityActivity represented by the frame.
completion: Option<RawSessionCompletion>Session table entry completed by the frame, if any.
Implementations
Sourceimpl RawSessionOutput
impl RawSessionOutput
Sourcepub fn new(
frame: Vec<u8>,
activity: RawActivity,
completion: Option<RawSessionCompletion>,
) -> Self
pub fn new( frame: Vec<u8>, activity: RawActivity, completion: Option<RawSessionCompletion>, ) -> Self
Creates pre-encoded output with activity metadata.